@@ -5,10 +5,15 @@ from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, Union
 
 import pyproj
 import simplejson as json
+from defusedxml import cElementTree as etree
+from requests import Response
 from shapely.geometry import LineString, Point, Polygon, box
 from shapely.ops import transform
 
-from .exceptions import InvalidInputType
+from .exceptions import InvalidInputType, ThreadingException, ZeroMatched
+
+DEF_CRS = "epsg:4326"
+BOX_ORD = "(west, south, east, north)"
 
 
 def threading(
@@ -48,7 +53,7 @@ def threading(
             try:
                 data.append(future.result())
             except Exception as exc:
-                raise Exception(f"{itr}: {exc}")
+                raise ThreadingException(itr, exc)
     return data
 
 
@@ -145,7 +150,7 @@ class ESRIGeomQuery:
     def bbox(self) -> Dict[str, str]:
         """Query for a bbox."""
         if len(self.geometry) != 4:
-            raise InvalidInputType("geometry (bbox)", "tuple", "(west, south, east, north)")
+            raise InvalidInputType("geometry (bbox)", "tuple", BOX_ORD)
 
         geo_type = "esriGeometryEnvelope"
         geo_json = dict(zip(("xmin", "ymin", "xmax", "ymax"), self.geometry))
@@ -195,7 +200,7 @@ class MatchCRS:
         geom: Tuple[float, float, float, float], in_crs: str, out_crs: str
     ) -> Tuple[float, float, float, float]:
         if not isinstance(geom, tuple) and len(geom) != 4:
-            raise InvalidInputType("geom", "tuple of length 4", "(west, south, east, north)")
+            raise InvalidInputType("geom", "tuple of length 4", BOX_ORD)
 
         project = pyproj.Transformer.from_crs(in_crs, out_crs, always_xy=True).transform
         return transform(project, box(*geom)).bounds
@@ -214,11 +219,11 @@ class MatchCRS:
 def check_bbox(bbox: Tuple[float, float, float, float]) -> None:
     """Check if an input inbox is a tuple of length 4."""
     if not isinstance(bbox, tuple) or len(bbox) != 4:
-        raise InvalidInputType("bbox", "tuple", "(west, south, east, north)")
+        raise InvalidInputType("bbox", "tuple", BOX_ORD)
 
 
 def bbox_resolution(
-    bbox: Tuple[float, float, float, float], resolution: float, bbox_crs: str = "epsg:4326"
+    bbox: Tuple[float, float, float, float], resolution: float, bbox_crs: str = DEF_CRS
 ) -> Tuple[int, int]:
     """Image size of a bounding box WGS84 for a given resolution in meters.
 
@@ -238,7 +243,7 @@ def bbox_resolution(
     """
     check_bbox(bbox)
 
-    bbox = MatchCRS.bounds(bbox, bbox_crs, "epsg:4326")
+    bbox = MatchCRS.bounds(bbox, bbox_crs, DEF_CRS)
     west, south, east, north = bbox
     geod = pyproj.Geod(ellps="WGS84")
 
@@ -254,7 +259,7 @@ def bbox_resolution(
 def vsplit_bbox(
     bbox: Tuple[float, float, float, float],
     resolution: float,
-    box_crs: str = "epsg:4326",
+    box_crs: str = DEF_CRS,
     max_pixel: int = 8000000,
 ) -> Tuple[List[Tuple[float, float, float, float]], List[int]]:
     """Split the bounding box vertically for WMS requests.
@@ -276,7 +281,7 @@ def vsplit_bbox(
     tuple
         The first element is a list of bboxes and the second one is width of the last bbox
     """
-    _crs = "epsg:4326"
+    _crs = DEF_CRS
     check_bbox(bbox)
     _bbox = MatchCRS.bounds(bbox, box_crs, _crs)
     width, height = bbox_resolution(_bbox, resolution, _crs)
@@ -306,3 +311,10 @@ def vsplit_bbox(
         bboxs = [bbox]
         widths = [width]
     return bboxs, widths
+
+
+def check_response(resp: Response) -> None:
+    """Check if a ``requests.Resonse`` returned an error message."""
+    if resp.headers["Content-Type"] == "application/xml":
+        root = etree.fromstring(resp.text)
+        raise ZeroMatched(root[0][0].text.strip())
